@@ -17,7 +17,7 @@ use Lemonldap::Config::Parameters;
 #}
 #### common declaration #######
 our (@ISA, $VERSION, @EXPORTS);
-$VERSION = '0.06';
+$VERSION = '0.07';
 our $VERSION_LEMONLDAP="1.1" ;
 our $VERSION_INTERNAL="0.03-4" ;
 
@@ -149,14 +149,14 @@ if ($ID_HANDLER) {
  print STDERR "domain $DOMAIN\n";
     if ($DOMAIN) {  
     	$GENERAL = $CONF->getDomain($DOMAIN) ;
-	my $tmpconf = $GENERAL->{$ID_HANDLER}; 
+	my $tmpconf = $GENERAL->{handler}->{$ID_HANDLER}; 
 	$COOKIE = $GENERAL->{Cookie};
         $PORTAL=$GENERAL->{Portal};
         $CACHE =$GENERAL->{Session} ;
-        parseConfig($tmpconf);
+       parseConfig($tmpconf);
     		}  else 		{ 
 	$tmpconf= $CONF->{$ID_HANDLER} ;
-        parseconfig($tmpconf); 
+        parseConfig($tmpconf); 
 			}
 	} 
 
@@ -347,7 +347,13 @@ my $complement;
                                                # in order to access at application 
 	   $etat =1 ;# We open tge gate
            $complement =$session{$ATTRLDAP}{$LDAPCONTROL};
-                                   } 
+#### begin:  here for he compatibility  with older lemonldap
+            $complement=~  s/#.*//;
+###  end  :  here for he compatibility  with older lemonldap
+
+
+
+                                     } 
 ### end of control                                      
      if ($etat) { 
 	 print STDERR "$ID_HANDLER: controle: $dn $uri :ACCEPTED \n" if $DEBUG;
@@ -465,6 +471,17 @@ sub proxy_handler {
 	$request->content($buf);
 	$request->content_type($r->content_type);
     }
+###begin: some modification like mod_proxy does
+if ($request->header('Host')){
+    my $host =$request->header('Host') ;
+    $host=~ s/$BASEPUB/$BASEPRIV/ ;
+    $request->header('Host' => $host);
+
+}
+### here I modify keep alive by close
+if ($request->header('Connection')){
+      $request->header('Connection' => 'close');
+}
 
     print STDERR  "$ID_HANDLER: request ".$request->as_string()."\n" if($DEBUG);
    if ($RECURSIF) { 
@@ -481,20 +498,24 @@ print STDERR  "$ID_HANDLER:OUTPUT PROXY:$PROXYEXT\n" if ($DEBUG);
     $UA->proxy(http  => $PROXYEXT);
 } 
     my $response = $UA->request($request);
-    $r->content_type($response->header('Content-type'));
+### begin: somes bad requests have bad header . 
+    my $content = $response->header('Content-type');
+     $content=~ s/,/;/g ;
+### end: somes bad requests have bad header . 
+    $r->content_type($content);
+### begin: I correct on the fly some incomming header like mod_proxy does
+if ($response->header('Location')) {
+  my $h =$response->header('Location');
+   $h=~ s/$BASEPRIV/$BASEPUB/ ;
+$response->header('Location' => $h);
+}
+### end: I correct on the fly some incomming header like mod_proxy does
 
     $r->status($response->code);
     $r->status_line(join " ", $response->code, $response->message);
     $response->scan(sub {
 	$r->headers_out->add(@_);
     });
-if ($r->header_out('Location')) {
-  my $h =$r->header_out('Location');
-   $h=~ s/$BASEPRIV/$BASEPUB/ ;
-$r->header_out('Location' => $h);
-}
-
-
 
     if ($r->header_only) {
 	$r->send_http_header();
@@ -578,7 +599,7 @@ sub parseConfig {
     $ATTRLDAP= $tmp->{AttrLdap};
     $LDAPCONTROL=$tmp->{CodeAppli};
     $DISABLEDCONTROL=$tmp->{Disabled};
-    $BASEPUB=$tmp->{Basepub};
+    $BASEPUB=$tmp->{BasePub};
     $BASEPRIV=$tmp->{BasePriv};
     $STOPCOOKIE= $tmp->{StopCookie};
     $PROXYEXT = $tmp->{ProxyExt};
@@ -592,6 +613,8 @@ __END__
 
 Lemonldap::Handlers::Generic - Perl extension for Lemonldap sso system
 
+Lemonldap::Handlers::Generic4a2  - Handler for Apache2 Lemonldap SSO system 
+
 =head1 SYNOPSIS
 
 In httpd.conf 
@@ -737,6 +760,8 @@ under the terms of the GNU General Public License version 2.
 =item Portions are copyrighted by Doug MacEachern and Lincoln Stein.
 This library is under the GNU General Public License, Version 2.
 
+=item Portage under Apache2 is made with help of : Ali Pouya and 
+Shervin Ahmadi (MINEFI/DGI) 
 
 =back
 
